==> haskell-servant-client-core-0.18.2-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-client-core
version:              0.18.2
visibility:           public
id:                   servant-client-core-0.18.2-JxiAsApfWuO2fIl60AUKud
key:                  servant-client-core-0.18.2-JxiAsApfWuO2fIl60AUKud
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    Core functionality and class for client function generation for servant APIs

description:
    This library provides backend-agnostic generation of client functions. For
    more information, see the README.

category:             Servant, Web
abi:                  e2349646f3ecc7187f9f0948981326b3
exposed:              True
exposed-modules:
    Servant.Client.Core Servant.Client.Core.Auth
    Servant.Client.Core.BaseUrl Servant.Client.Core.BasicAuth
    Servant.Client.Core.ClientError Servant.Client.Core.HasClient
    Servant.Client.Core.Reexport Servant.Client.Core.Request
    Servant.Client.Core.Response Servant.Client.Core.RunClient
    Servant.Client.Free Servant.Client.Generic

hidden-modules:       Servant.Client.Core.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/servant-client-core-0.18.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/servant-client-core-0.18.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/servant-client-core-0.18.2

hs-libraries:         HSservant-client-core-0.18.2-JxiAsApfWuO2fIl60AUKud
depends:
    aeson-1.5.6.0-GONgLS6yTtf17t9dlS8fIx base-4.14.1.0
    base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3
    base64-bytestring-1.2.0.1-3dX39isVKnJ9vuK9OH6kQ
    bytestring-0.10.12.0 containers-0.6.2.1 deepseq-1.4.4.0
    exceptions-0.10.4 free-5.1.6-9Umi5fXVbOOBxDCDTbVT07
    http-media-0.8.0.0-83ECX5PF2KG6MDKup6sRqB
    http-types-0.12.3-EhuIez3q1reELpcE0UXNI1
    network-uri-2.6.4.1-FEk4aE8j9Y63aWdVbJOWgW
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    servant-0.18.2-6mdas0swsxv73MKEDcvOdz
    sop-core-0.5.0.1-LSgc1wfRk3m3wHkiLjj5ug template-haskell-2.16.0.0
    text-1.2.4.1 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-servant-client-core/html/servant-client-core.haddock

haddock-html:         /usr/share/doc/haskell-servant-client-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-client-core-0.18.2-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-client-core
version:              0.18.2
visibility:           public
id:                   servant-client-core-0.18.2-JKwtkwAFgtv2skXXW9bZs5
key:                  servant-client-core-0.18.2-JKwtkwAFgtv2skXXW9bZs5
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    Core functionality and class for client function generation for servant APIs

description:
    This library provides backend-agnostic generation of client functions. For
    more information, see the README.

category:             Servant, Web
abi:                  f7ea5944c893cffbf699ce0c2f1b99ce
exposed:              True
exposed-modules:
    Servant.Client.Core Servant.Client.Core.Auth
    Servant.Client.Core.BaseUrl Servant.Client.Core.BasicAuth
    Servant.Client.Core.ClientError Servant.Client.Core.HasClient
    Servant.Client.Core.Reexport Servant.Client.Core.Request
    Servant.Client.Core.Response Servant.Client.Core.RunClient
    Servant.Client.Free Servant.Client.Generic

hidden-modules:       Servant.Client.Core.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/servant-client-core-0.18.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/servant-client-core-0.18.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/servant-client-core-0.18.2

hs-libraries:         HSservant-client-core-0.18.2-JKwtkwAFgtv2skXXW9bZs5
depends:
    aeson-1.5.6.0-I7BbKEwOl3UEL7J6p5LGbn base-4.14.1.0
    base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3
    base64-bytestring-1.2.0.1-LSGBjcCPG61N7rhXbNth1
    bytestring-0.10.12.0 containers-0.6.2.1 deepseq-1.4.4.0
    exceptions-0.10.4 free-5.1.6-1IXBBF2i9ekIacrPukUJEO
    http-media-0.8.0.0-5ITL5sY0lt3I8fmpe3ZDK2
    http-types-0.12.3-K6U5ABdDf9a5rAhqpLKr8V
    network-uri-2.6.4.1-J4xKR5bjyl4EwNDOZsZp7W
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    servant-0.18.2-Gmx2ytb34m9KpyhdMBw5Ru
    sop-core-0.5.0.1-LSgc1wfRk3m3wHkiLjj5ug template-haskell-2.16.0.0
    text-1.2.4.1 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-servant-client-core/html/servant-client-core.haddock

haddock-html:         /usr/share/doc/haskell-servant-client-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
